@@ -62,7 +62,7 @@ class TsApi:
         if r.status_code < 400:
             return r.json()
         else:
-            print(r.json(), file=sys.stderr, flush=True)
+            print(r.text, file=sys.stderr, flush=True)
             raise Exception(f'HTTP status: {r.status_code}, url: {r.url}')
 
     def get_task_script_build_info(self, id: str):
@@ -74,7 +74,7 @@ class TsApi:
         if r.status_code < 400:
             return r.json()
         else:
-            print(r.json(), file=sys.stderr, flush=True)
+            print(r.text, file=sys.stderr, flush=True)
             raise Exception(f'HTTP status: {r.status_code}, url: {r.url}')
 
     def get_task_script_build_logs(self, id: str, params):
@@ -87,5 +87,5 @@ class TsApi:
         if r.status_code < 400:
             return r.json()
         else:
-            print(r.json(), file=sys.stderr, flush=True)
+            print(r.text, file=sys.stderr, flush=True)
             raise Exception(f'HTTP status: {r.status_code}, url: {r.url}')
