@@ -11,8 +11,8 @@ from .__utils import sizeof_fmt, zipdir
 
 def put_cmd_args(parser: argparse.ArgumentParser):
     parser.add_argument('type', type=str, choices=['ids', 'protocol', 'master-script', 'task-script'], help='artifact type')
-    parser.add_argument('namespace', type=str)
-    parser.add_argument('slug', type=str)
+    parser.add_argument('namespace', type=str.lower)
+    parser.add_argument('slug', type=str.lower)
     parser.add_argument('version', type=__version_type)
     parser.add_argument('folder', type=__folder_type, help='path to folder to be uploaded')
     parser.add_argument(
@@ -48,16 +48,18 @@ def __ensure_args(args: argparse.Namespace):
     for k, v in os.environ.items():
         if k.startswith(env_prefix):
             arg_key = k.replace(env_prefix, '').lower()
-            if getattr(args, arg_key, None) is None:
+            if getattr(args, arg_key, None) in [None, False]:
                 setattr(args, arg_key, v)
 
     # from config
     if args.config:
         parsed_config = json.load(args.config)
         for k, v in parsed_config.items():
-            if getattr(args, k, None) is None:
+            if getattr(args, k, None) in [None, False]:
                 setattr(args, k, v)
 
+    args.ignore_ssl = args.ignore_ssl in [True, 'true', 'True', '1']
+
 
 def __cmd(args):
     __ensure_args(args)
