@@ -51,8 +51,8 @@ class Command:
 
             time_elapsed = 0
             while time_elapsed <= ttl_sec:
-                time.sleep(5)
-                time_elapsed += 5
+                time.sleep(1)
+                time_elapsed += 1
                 command_response = requests.request("GET", command_url, headers=command_headers, verify=False)
                 print("Polling for command status")
                 if command_response.status_code == 200:
@@ -64,7 +64,7 @@ class Command:
                     elif command_status == "CREATED" or command_status == "PENDING" or command_status == "PROCESSING":
                         continue
                     else:
-                        raise Exception("Command status is " + command_status)
+                        raise Exception(command.get("responseBody"))
 
             if time_elapsed >= ttl_sec:
                 print('TTL for command has expired')
