@@ -261,7 +261,8 @@ class Datalake:
                     'fileKey': file_key,
                     'fileId': file_id
                 },
-                labels=labels
+                labels=labels,
+                sse_kms_key_id=get_kms_key_name(org_slug)
             )
 
         if hasattr(content, 'read'):
@@ -408,8 +409,14 @@ class Datalake:
 
         return None
 
-    def create_labels_file(self, target_file, labels):
-        head = self.get_s3_head(target_file)
+    def create_labels_file(self, target_file, labels, sse_kms_key_id = None):
+        if sse_kms_key_id == None:
+            try:
+                head = self.get_s3_head(target_file)
+                sse_kms_key_id = head.get('SSEKMSKeyId', '')
+            except Exception as e:
+                print(e)
+                sse_kms_key_id = ''
         file_key = os.path.join(target_file['fileKey'], f'{target_file["fileId"]}.labels')
         params = {
             'Bucket': target_file['bucket'],
@@ -417,10 +424,13 @@ class Datalake:
                 .replace('/RAW/', '/TMP/')
                 .replace('/IDS/', '/TMP/')
                 .replace('/PROCESSED/', '/TMP/'),
-            'ServerSideEncryption': 'aws:kms',
-            'SSEKMSKeyId': head.get('SSEKMSKeyId', ''),
             'ContentType': 'application/json'
         }
+        if sse_kms_key_id != '':
+            params['ServerSideEncryption'] = 'aws:kms'
+            params['SSEKMSKeyId'] = sse_kms_key_id
+        else:
+            params['ServerSideEncryption'] = 'AES256'
         response = self.s3.put_object(Body=json.dumps(labels), **params)
         print({ 'level': 'debug', 'message': 'labels file created', 'response': response })
 
