@@ -10,6 +10,16 @@ url = os.environ.get('ORCHESTRATOR_ENDPOINT')
 task_group_hash = os.environ.get('TASK_GROUP_HASH')
 container_id = os.environ.get('CONTAINER_ID')
 
+def es_hit_to_file_pointer(hit):
+  es_file = hit['_source']['file']
+  return {
+    'type': 's3file',
+    'bucket': es_file['bucket'],
+    'fileKey': es_file['path'],
+    'version': es_file['version'],
+    'fileId': hit['_source']['fileId']
+  }
+
 def es_datalake_search_eql(payload):
   try:
     search_url = url + '/datalake/searchEql'
@@ -25,7 +35,7 @@ def es_datalake_search_eql(payload):
       verify=False
     )
     if response.status_code >= 400:
-      print({ 'level': 'debug', 'message': response.text })
+      print({ 'level': 'error', 'message': response.text })
       raise Exception(f'Got {response.status_code} for {search_url}')
     return response.json()
   except RequestException:
